Method: Azure::ServiceBus::Relay#initialize

Defined in:
lib/azure/service_bus/relay.rb

#initialize(name, options = {}) ⇒ Relay

Public: Initialize the relay endpoint.

Attributes

  • name - A String with the name of the relay endpoint.

  • options - The resource options Hash

Options

Accepted key/value pairs in options parameter are:

  • :relay_type - String. Determines the type of the relay endpoint. This is required.

  • :requires_client_authorization - Boolean. Determines whether or not clients need to authenticate when making calls.

  • :requires_transport_security - Boolean. Determines whether or not the endpoint uses transport security.



34
35
36
37
38
39
40
# File 'lib/azure/service_bus/relay.rb', line 34

def initialize(name, options = {})
  normalized_options = {}
  normalized_options["RelayType"] = options[:relay_type].to_s
  normalized_options["RequiresClientAuthorization"] = options[:requires_client_authorization].to_s if options.has_key?(:requires_client_authorization)
  normalized_options["RequiresTransportSecurity"] = options[:requires_transport_security].to_s if options.has_key?(:requires_transport_security)
  super(name, normalized_options)
end