Method: Azure::ServiceBus::ServiceBusService#peek_lock_queue_message
- Defined in:
- lib/azure/service_bus/service_bus_service.rb
#peek_lock_queue_message(queue, options = {}) ⇒ Object
Automatically retrieves and locks a message from a queue for processing. The message is guaranteed not to be delivered to other receivers (on the same subscription only) during the lock duration period specified in the queue description. Once the lock expires, the message will be available to other receivers. In order to complete processing of the message, the receiver should issue a delete command with the lock ID received from this operation. To abandon processing of the message and unlock it for other receivers, an Unlock Message command should be issued, or the lock duration period can expire.
Attributes
-
queue- String. Either a Azure::ServiceBus::Queue instance or a string of the queue name -
options- Hash. Optional parameters.
Options
Accepted key/value pairs in options parameter are:
-
:timeout- Integer. Timeout for the REST call.
511 512 513 |
# File 'lib/azure/service_bus/service_bus_service.rb', line 511 def (queue, ={}) (_name_for(queue), [:timeout] ? [:timeout] : DEFAULT_TIMEOUT) end |