Method: Azure::ServiceBus::ServiceBusService#unlock_queue_message

Defined in:
lib/azure/service_bus/service_bus_service.rb

#unlock_queue_message(message) ⇒ Object

Unlocks a message for processing by other receivers on a given subscription. This operation deletes the lock object, causing the message to be unlocked. A message must have first been locked by a receiver before this operation is called.

Attributes

  • message - String. Either the message location URL or a message object.



524
525
526
# File 'lib/azure/service_bus/service_bus_service.rb', line 524

def unlock_queue_message(message)
  _unlock_message(message)
end