Method: Azure::ServiceBus::ServiceBusService#create_queue
- Defined in:
- lib/azure/service_bus/service_bus_service.rb
#create_queue(queue, options = {}) ⇒ Object
Creates a new queue. Once created, this queue’s resource manifest is immutable.
Attributes
-
queue- Azure::ServiceBus::Queue instance to create on server, or a string of the queue name -
options- Hash. The queue properties.
Options
Accepted key/value pairs in options parameter are:
-
:default_message_time_to_live- XML datetime. Determines how long a message lives in the associated subscriptions. -
:duplicate_detection_history_time_window- XML datetime. Specifies the time span during which the Service Bus will detect message duplication. -
:enable_batched_operations- Boolean. Enables or disables service side batching behavior when performing operations for the specific queue. -
:dead_lettering_on_message_expiration:- Boolean. This field controls how the Service Bus handles a message whose TTL has expired. -
:lock_duration- XML datetime. Determines the amount of time in seconds in which a message should be locked for processing by a receiver. -
:max_delivery_count- Number. A message is automatically deadlettered after this number of deliveries. -
:max_size_in_megabytes- Number. Specifies the maximum topic size in megabytes -
:message_count- Number. Displays the number of messages currently in the queue. -
:requires_duplicate_detection- Boolean. If enabled, the topic will detect duplicate messages within the time span specified by the DuplicateDetectionHistoryTimeWindow property -
:requires_session- Boolean. If set to true, the queue will be session-aware and only SessionReceiver will be supported. -
:size_in_bytes- Number. Reflects the actual bytes toward the topic quota that messages in the topic currently occupy.
123 124 125 126 |
# File 'lib/azure/service_bus/service_bus_service.rb', line 123 def create_queue(queue, ={}) queue = _new_or_existing(Azure::ServiceBus::Queue, queue, ? : {}) create_resource_entry(:queue, queue, queue.name) end |